@@ -137,12 +137,12 @@ random_template_variables_converter=RandomTemplateVariablesConverter()
 class FileTemplateVariablesConverter(Converter):
     def to_entity(self, do: FileTemplateVariablesDO):
         return FileTemplateVariables(
-            variables = [UStr(m) for m in do.variables],
+            variables = None if do.variables is None else [UStr(m) for m in do.variables],
             path = UStr(do.path)
         )
     def to_do(self, x:FileTemplateVariables):
         return FileTemplateVariablesDO(
-            variables = [m.get_value() for m in x.variables],
+            variables = None if x.variables is None else [m.get_value() for m in x.variables],
             path = x.path.get_value()
         )
 file_template_variables_converter=FileTemplateVariablesConverter()
