@@ -14,8 +14,14 @@ class DatapipeServerInfo(Entity):
         self,
         id: UStr,
         secret: UStr,
-        endpoint: UStr
+        endpoint: UStr,
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.id = id
         self.secret = secret
         self.endpoint = endpoint
@@ -28,8 +34,14 @@ class DatapipeDataInfo(Entity):
         bucket: UStr,
         remote_path: UStr,
         local_path: UStr,
-        timeout: UInt = 3
+        timeout: UInt = 3,
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.bucket = bucket
         self.remote_path = remote_path
         self.local_path = local_path
@@ -41,8 +53,14 @@ class ClusterConfigData(Entity):
     def __init__(
         self,
         data_server: DatapipeServerInfo,
-        data: List[DatapipeDataInfo]
+        data: List[DatapipeDataInfo],
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.data_server = data_server
         self.data = data
 
@@ -55,8 +73,14 @@ class ClusterConfig(Entity):
         region_id: UStr,
         config_data: Optional[ClusterConfigData] = None,
         entry_point: Optional[List[UStr]] = None,
-        timeout: UInt = 20
+        timeout: UInt = 20,
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.cluster_name = cluster_name
         self.region_id = region_id
         self.config_data = config_data
@@ -71,8 +95,14 @@ class BootstrapInfo(Entity):
         cluster_config: ClusterConfig,
         template: UStr = 'normal',
         platform: UStr = 'aliyun',
-        patch_setting: Optional[UDict] = None
+        patch_setting: Optional[UDict] = None,
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.cluster_config = cluster_config
         self.template = template
         self.platform = platform
@@ -84,8 +114,14 @@ class RandomTemplateVariables(Entity):
     def __init__(
         self,
         variables: List[UStr],
-        lengths: Optional[List[UInt]] = None
+        lengths: Optional[List[UInt]] = None,
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.variables = variables
         self.lengths = lengths
 
@@ -94,9 +130,15 @@ class RandomTemplateVariables(Entity):
 class FileTemplateVariables(Entity):
     def __init__(
         self,
-        variables: List[UStr],
-        path: UStr
+        variables: Optional[List[UStr]],
+        path: UStr,
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.variables = variables
         self.path = path
 
@@ -106,7 +148,13 @@ class FilesTemplateVariables(Entity):
     def __init__(
         self,
         variables: List[UStr],
-        paths: List[UStr]
+        paths: List[UStr],
+        **kwargs
     ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
         self.variables = variables
         self.paths = paths
\ No newline at end of file
