@@ -19,6 +19,10 @@ class ValueObject:
         return self.value
 
 
+    def __repr__(self) -> str:
+        return str(self.value)
+
+
 class U(ValueObject):
     pass
 
